@@ -11,6 +11,7 @@ def main():
                                          'If local image not specified will be set to remote_image',
                         nargs='+',
                         required=True)
+    parser.add_argument('--image_prefix', help='Common prefix for all pushed images')
     parser.add_argument('--on_tag_exist', help='replace or raise if tag already exist',
                         choices=['replace', 'raise'])
     parser.add_argument('--all_tenants', action='store_true', help='If passed perform operation on all tenants')
@@ -24,13 +25,18 @@ def main():
         push(args.tenant, args.version, args.config_path, images=args.images,
              equal_tags=args.equal_tags, all_tenants=args.all_tenants, local_version=args.local_version,
              auto_incr_version=args.auto_incr_version,
-             on_repository_not_exist=args.on_repository_not_exist)
+             on_repository_not_exist=args.on_repository_not_exist,
+             docker_compose_path=args.docker_compose_path,
+             image_prefix=args.image_prefix, compose_services=args.compose_services,
+             compose_build_cmd=args.compose_build_cmd)
     elif args.command == 'rollback':
         rollback(args.tenant, args.version, args.config_path,
                  prev_release_version=args.prev_release, images=args.images,
                  all_tenants=args.all_tenants,
                  local_version=args.local_version,
-                 delete_all_equal_tags=args.all_tags)
+                 delete_all_equal_tags=args.all_tags,
+                 docker_compose_path=args.docker_compose_path,
+                 image_prefix=args.image_prefix, compose_services=args.compose_services)
     else:
         raise ValueError('Unknown command. Available push and rollback')
 
